pub struct AuthOptions {
pub allow_device_credential: Option<bool>,
pub cancel_title: Option<String>,
pub fallback_title: Option<String>,
pub title: Option<String>,
pub subtitle: Option<String>,
pub confirmation_required: Option<bool>,
}Fields
allow_device_credential: Option<bool>Enables authentication using the device’s password. This feature is available on both Android and iOS.
cancel_title: Option<String>Label for the Cancel button. This feature is available on both Android and iOS.
fallback_title: Option<String>Specifies the text displayed on the fallback button if biometry authentication fails. This feature is available iOS only.
title: Option<String>Title indicating the purpose of biometry verification. This feature is available Android only.
subtitle: Option<String>SubTitle providing contextual information of biometry verification. This feature is available Android only.
confirmation_required: Option<bool>Specifies whether additional user confirmation is required, such as pressing a button after successful biometry authentication. This feature is available Android only.